rulebase.rules.interval\_based\_operations.builtin\_application module
======================================================================

.. automodule:: rulebase.rules.interval_based_operations.builtin_application
    :members:
    :undoc-members:
    :show-inheritance:
